@@ -45,6 +45,7 @@ class DocumentField:
         self.__parent_dict = parent_dict
         self.__update_immediately = update_immediately
         self.__update_func = update_func
+        self.__index = 0
 
     def __getattr__(self, item):
         if not isinstance(item, str):
@@ -101,6 +102,18 @@ class DocumentField:
     def __dict__(self):
         return self.__parent_dict
 
+    def __iter__(self):
+        self.__index = 0
+        return self
+
+    def __next__(self):
+        try:
+            result = list(self.__parent_dict.keys())[self.__index]
+            self._index += 1
+            return result
+        except IndexError:
+            raise StopIteration()
+
 
 class DocumentArrayField:
 
@@ -108,6 +121,7 @@ class DocumentArrayField:
         self.__parent_list = parent_list
         self.__update_immediately = update_immediately
         self.__update_func = update_func
+        self.__index = 0
 
     def append(self, item):
         self.__parent_list.append(item)
@@ -160,6 +174,18 @@ class DocumentArrayField:
         else:
             return self.__parent_list[item]
 
+    def __iter__(self):
+        self.__index = 0
+        return self
+
+    def __next__(self):
+        try:
+            result = self[self.__index]
+            self.__index += 1
+            return result
+        except IndexError:
+            raise StopIteration()
+
 
 class MetaDocument(type):
     collection: AsyncIOMotorCollection
